@@ -1,5 +1,4 @@
 import os
-import tempfile
 
 import pytest
 from d8s_lists import iterables_have_same_items
@@ -26,7 +25,6 @@ from d8s_file_system import (
     home_directory,
     home_directory_join,
     is_directory,
-    temp_dir_create,
 )
 
 NON_EXISTENT_DIRECTORY_PATH = './foo'
@@ -130,11 +128,18 @@ def test_directory_delete_docs_1():
 
 
 def test_home_directory_docs_1():
+    # '/root' is the home directory when running in linux, '/home/runner' is the home directory in mac (at least in github actions), and '/Users/runner' is the home directory on windows (in github actions)
+    HOME_DIRECTORIES = ('/root', '/home/runner', '/Users/runner')
     result = home_directory()
-    assert result == '/root'
+    assert result in HOME_DIRECTORIES
 
+    JOINED_HOME_DIRECTORIES = (
+        '/root/./test_directories',
+        '/home/runner/./test_directories',
+        '/Users/runner/./test_directories',
+    )
     result = home_directory_join(EXISTING_DIRECTORY_PATH)
-    assert result == '/root/./test_directories'
+    assert result in JOINED_HOME_DIRECTORIES
 
 
 def test_directory_files_containing_docs_1():
@@ -281,9 +286,3 @@ def test_directory_subdirectory_names_docs_1():
 def test_is_directory_docs_1():
     assert is_directory(EXISTING_DIRECTORY_PATH)
     assert not is_directory(NON_EXISTENT_DIRECTORY_PATH)
-
-
-def test_temp_dir_create_docs_1():
-    temp_dir = temp_dir_create()
-    assert isinstance(temp_dir, tempfile.TemporaryDirectory)
-    temp_dir.cleanup()
